cmoncrawl.processor.pipeline.downloader.DownloaderDummy.download
================================================================

.. currentmodule:: cmoncrawl.processor.pipeline.downloader

.. automethod:: DownloaderDummy.download